#! /usr/local/bin/node

let args = process.argv;
let input = args[2];
let output = args[3];

var fs = require('fs');
var path = require('path');
var less = require('less');
let LessPluginAutoPrefix = require('less-plugin-autoprefix');
let NpmImportPlugin = require("less-plugin-npm-import");
var LessPluginCleanCSS = require('less-plugin-clean-css');

var includesDir = path.dirname(input);
ensureDirectoryExistence(output);

let autoprefixPlugin = new LessPluginAutoPrefix({
    browsers: ["last 2 versions"]
});
let npmInportPlugin = new NpmImportPlugin();
let cleanCSSPlugin = new LessPluginCleanCSS({
    sourceMapInlineSources: true
});

fs.readFile(input, 'utf-8', function(err, data) {
    if (err) {
        console.log(err);
    } else {
        less.render(data, {
                plugins: [autoprefixPlugin, npmInportPlugin],
                paths: includesDir
            })
            .then(function(result) {
                fs.writeFile(output, result.css, function(err) {
                    if (err) {
                        console.log(err);
                    }
                    console.log(input + ' compiled into ' + output);
                });
            }, function(err) {
                error(err);
            });
    }
})

//http://stackoverflow.com/questions/13542667/create-directory-when-writing-to-file-in-node-js
function ensureDirectoryExistence(filePath) {
    var dirname = path.dirname(filePath);
    if (directoryExists(dirname)) {
        return true;
    }
    ensureDirectoryExistence(dirname);
    try {
        fs.mkdirSync(dirname);
    } catch (e) {
        return;
    }
}

function directoryExists(path) {
    try {
        return fs.statSync(path).isDirectory();
    } catch (err) {
        return false;
    }
}

function error(str) {
    console.error(str);
    process.exit(1);
}
