import rollup from 'rollup';
import node from 'rollup-plugin-node-resolve';
import commonjs from 'rollup-plugin-commonjs';
import uglify from 'rollup-plugin-uglify';
import sourcemaps from 'rollup-plugin-sourcemaps';
import typescript from 'rollup-plugin-typescript';
import angular from 'rollup-plugin-angular';

export default {
    // entry: './src/main/cordova/src/ng-generated/js/main.js',
    entry: './src/ts/main.ts',
    dest: './bin/dist/js/main.js', // output a single application bundle
    sourceMap: true,
    format: 'iife',
    context: 'window',
    plugins: [
        angular(),
        typescript( {
            typescript: require( 'typescript' )
        } ),
        node( {
            jsnext: true,
            module: true,
            browser: true,
            extensions: [ '.js', '.ts' ]
        } ),
        commonjs( {
            include: 'node_modules/**',
        } ),
        // uglify()
        // sourcemaps() //debug the js files for accurate line numbers
    ],
    external: [
        '@angular/common',
        '@angular/compiler',
        '@angular/core',
        '@angular/core',
        '@angular/http',
        '@angular/platform-browser-dynamic',
        '@angular/platform-browser',
        '@angular/router',
    ],
    globals: {
        '@angular/common': 'vendor._angular_common',
        '@angular/compiler': 'vendor._angular_compiler',
        '@angular/core': 'vendor._angular_core',
        '@angular/forms': 'vendor._angular_forms',
        '@angular/http': 'vendor._angular_http',
        '@angular/platform-browser-dynamic': 'vendor._angular_platformBrowserDynamic',
        '@angular/platform-browser': 'vendor._angular_platformBrowser',
        '@angular/router': 'vendor._angular_router',
    }
};