#! /usr/local/bin/node

var rollup = require( 'rollup' );
var nodeResolve = require( 'rollup-plugin-node-resolve' );
var commonjs = require( 'rollup-plugin-commonjs' );
var sourcemaps = require( 'rollup-plugin-sourcemaps' );
var typescript = require( 'rollup-plugin-typescript' );
var angular = require( 'rollup-plugin-angular' );

var uglifyJS = require( "uglify-js" );
var fs = require( 'fs' );
var path = require( 'path' );

let nodePath = './node_modules/';
let dest = './bin/dist/js/vendor.js';

ensureDirectoryExistence( dest );
let files = [
    nodePath + '/zone.js/dist/zone.js',
    nodePath + '/reflect-metadata/Reflect.js'
];

var rollupConfig = {
    entry: './frontend-build/vendorjs.rollup.js',
    context: 'window',
    plugins: [
        nodeResolve( {
            jsnext: true,
            module: true
        } ),
        commonjs( {
            include: 'node_modules/rxjs/**',
        } ),
        // sourcemaps() debug the js files for accurate line numbers
    ]
};

var ugly = uglifyJS.minify( files, {
    mangle: false
} );

rollup.rollup( rollupConfig )
    .then( function ( roll ) {
        var uglyCode = ugly.code;
        var bundle = roll.generate( {
            format: 'iife',
            moduleName: 'vendor'
        } );
        var code = ugly.code + '\n' + bundle.code;
        fs.writeFile( dest, code, function ( err ) {
            if ( err ) {
                console.log( err );
            }
            console.log( dest + ' created' );
        } );
    } );


//http://stackoverflow.com/questions/13542667/create-directory-when-writing-to-file-in-node-js
function ensureDirectoryExistence( filePath ) {
    var dirname = path.dirname( filePath );
    if ( directoryExists( dirname ) ) {
        return true;
    }
    ensureDirectoryExistence( dirname );
    try {
        fs.mkdirSync( dirname );
    } catch ( e ) {
        return;
    }

}

function directoryExists( path ) {
    try {
        return fs.statSync( path ).isDirectory();
    } catch ( err ) {
        return false;
    }
}